/*********************************************************************
 * Job Ticket API (JTAPI)                                            
 *                                                                   
 * Copyright (c) 2003 International Business Machines Corp.          
 * Copyright (c) 2003 Free Standards Group.          
 *
 *                    Common Public License - v 1.0 
 * THE ACCOMPANYING PROGRAM IS PROVIDED UNDER THE TERMS OF THIS COMMON 
 * PUBLIC LICENSE ("AGREEMENT"). ANY USE, REPRODUCTION OR DISTRIBUTION 
 * OF THE PROGRAM CONSTITUTES RECIPIENT'S ACCEPTANCE OF THIS AGREEMENT.   
 *
 * The Common Public License in its entirety is located in 
 * jtapi_cpl.h and applies to the contents of this file. 
 *********************************************************************/
#ifndef JTAPI_ENUMS_H
#define JTAPI_ENUMS_H

/************************************************************
 * BindingTypeEnum
 *
 * Whether or not to bind and what kind of binding to use.
 ***********************************************************/
#define BD_CHANNEL      "CHANNEL" 
#define BD_EDGE_GLUE    "EDGE_GLUE"
#define BD_NONE         "NONE"
#define BD_PERFECT      "PERFECT"
#define BD_PLASTIC_COMB "PLASTIC_COMB"
#define BD_RING         "RING"
#define BD_SPIRAL       "SPIRAL"
#define BD_STRIP        "STRIP"
#define BD_TAPE         "TAPE"
#define BD_THREAD_SEAL  "THREAD_SEAL"
#define BD_VELO         "VELO"
#define BD_WIRE_COMB    "WIRE_COMB"

/************************************************************ 
 * Boolean type 
 *
 * Used for boolean values. 
 ***********************************************************/
typedef int jtapi_boolean_t;
#define true   1
#define false  0
#define not_set -1

/************************************************************
 * CollateEnum
 *
 * Whether the sheets and/or documents are to be collated or 
 * not.
 ***********************************************************/
typedef enum
{
   CL_NOT_SET = 0,
   CL_NONE,
   CL_SHEET,
   CL_SHEET_AND_DOC
} jtapi_collate_t;

/************************************************************
 * CompressionEnum
 *
 * Type of compression algorithm to use for the data 
 * contained in the document.
 ***********************************************************/
#define CM_COMPRESS "COMPRESS"
#define CM_DEFLATE  "DEFLATE" 
#define CM_GZIP     "GZIP"
#define CM_NONE     "NONE"

/************************************************************
 * ContactTypeEnum
 *
 * Role of the person that is to be contacted regarding the
 * job.
 ***********************************************************/
#define CT_ACCOUNTING     "ACCOUNTING"
#define CT_ADMINISTRATOR  "ADMINISTRATOR"
#define CT_APPROVER       "APPROVER"
#define CT_ART_RETURN     "ART_RETURN"
#define CT_CUSTOMER       "CUSTOMER" 
#define CT_DELIVERY       "DELIVERY"
#define CT_PICKUP         "PICKUP"
#define CT_SENDER         "SENDER"
#define CT_SUPPLIER       "SUPPLIER" 
#define CT_SURPLUS_RETURN "SURPLUS_RETURN"

/************************************************************
 * FeedOrientation
 * 
 * The orientation of the media as it is to be fed into the
 * device.
 ***********************************************************/
typedef enum
{
   FO_NOT_SET = 0,
   FO_LONG_EDGE_FIRST,
   FO_SHORT_EDGE_FIRST,
} jtapi_feed_orientation_t;

/************************************************************
 * FitPolicyEnum
 * 
 * How to modify the content to fit on the media.
 ***********************************************************/
typedef enum
{
   FP_NOT_SET = 0,
   FP_CLIP_TO_PAGE,
   FP_FIT_TO_PAGE,
   FP_ROTATE_AND_OR_FIT
} jtapi_fit_policy_t;

/************************************************************
 * FoldTypeEnum
 *
 * The type of folding to perform.
 ***********************************************************/
#define FD_NONE           "NONE"
#define FD_SADDLE         "SADDLE"
#define FD_Z              "Z"
#define FD_Z_IN_THIRDS    "Z_IN_THIRDS"
#define FD_C              "C"

/************************************************************
 * HoldEnum
 *
 * Whether or not to hold the job and for how long.
 ***********************************************************/
#define HD_NO_HOLD     "NO_HOLD"
#define HD_INDEFINITE  "INDEFINITE"

/************************************************************
 * ImageAlignmentXEnum
 *
 * How to align the image in the x direction.
 ***********************************************************/
typedef enum
{
   IAX_NOT_SET = 0,
   IAX_NONE,
   IAX_CENTER,
   IAX_LEFT,
   IAX_RIGHT, 
} jtapi_image_alignement_x_t;

/************************************************************
 * ImageAlignmentYEnum
 *
 * How to align the image in the y direction.
 ***********************************************************/
typedef enum
{
   IAY_NOT_SET = 0,
   IAY_NONE,
   IAY_BOTTOM,
   IAY_CENTER,
   IAY_TOP 
} jtapi_image_alignement_y_t;

/************************************************************
 * InputTrayNameEnum
 *
 * Names of the input trays.
 ***********************************************************/
#define IT_ANY_SMALL_FORMAT "ANY_SMALL_FORMAT"
#define IT_ANY_LARGE_FORMAT "ANY_LARGE_FORMAT"
#define IT_AUTO_SELECT      "AUTO_SELECT"
#define IT_BOTTOM           "BOTTOM"
#define IT_BYPASS_TRAY      "BYPASS_TRAY"
#define IT_BYPASS_TRAY_1    "BYPASS_TRAY_1"
#define IT_BYPASS_TRAY_2    "BYPASS_TRAY_2"
#define IT_BYPASS_TRAY_3    "BYPASS_TRAY_3"
#define IT_CONTINUOUS       "CONTINUOUS"
#define IT_DISC             "DISC" 
#define IT_DISC_1           "DISC_1" 
#define IT_DISC_2           "DISC_2" 
#define IT_DISC_3           "DISC_3"        
#define IT_ENVELOPE         "ENVELOPE"
#define IT_ENVELOPE_1       "ENVELOPE_1"
#define IT_ENVELOPE_2       "ENVELOPE_2"
#define IT_ENVELOPE_3       "ENVELOPE_3"
#define IT_FRONT            "FRONT"
#define IT_INSERT_TRAY      "INSERT_TRAY"
#define IT_INSERT_TRAY_1    "INSERT_TRAY_1"
#define IT_INSERT_TRAY_2    "INSERT_TRAY_2"
#define IT_INSERT_TRAY_3    "INSERT_TRAY_3"
#define IT_LARGE_CAPACITY   "LARGE_CAPACITY"
#define IT_LARGE_CAPACITY_1 "LARGE_CAPACITY_1"
#define IT_LARGE_CAPACITY_2 "LARGE_CAPACITY_2"
#define IT_LARGE_CAPACITY_3 "LARGE_CAPACITY_3"
#define IT_LEFT             "LEFT"
#define IT_MIDDLE           "MIDDLE"
#define IT_REAR             "REAR"
#define IT_RIGHT            "RIGHT"
#define IT_ROLL             "ROLL" 
#define IT_ROLL_1           "ROLL_1"
#define IT_ROLL_2           "ROLL_2"
#define IT_ROLL_3           "ROLL_3"
#define IT_SIDE             "SIDE"
#define IT_TOP              "TOP"
#define IT_TRAY             "TRAY"
#define IT_TRAY_1           "TRAY_1"
#define IT_TRAY_2           "TRAY_2"
#define IT_TRAY_3           "TRAY_3"

/************************************************************
 * InsertSheetContentEnum
 *
 * What is to appear on the insert sheet.
 ***********************************************************/
typedef enum
{
   IC_NOT_SET = 0,
   IC_BLANK,
   IC_DUPLICATE
} jtapi_insert_sheet_content_t;

/************************************************************
 * JobTicketTypeVersionEnum
 *
 * Type and version of the job ticket syntax.
 ***********************************************************/
#define JT_AUTO_DETECT "AUTO_DETECT"
#define JT_JDF_1_2     "JDF_1.2"
#define JT_OTHER       "OTHER"
#define JT_PWG         "PWG_1.0"

/************************************************************
 * JogOffsetEnum
 *
 * Whether or not the job and job copies are to be offset 
 * stacked.
 ***********************************************************/
typedef enum
{
   JO_NOT_SET = 0,
   JO_NONE,
   JO_ALTERNATE,
} jtapi_jog_offset_t;


/************************************************************
 * LengthUnitEnum
 *
 * Unit if measure to use when specifying length.
 ***********************************************************/
typedef enum
{
   LU_NOT_SET = 0,
   LU_MICROMETERS,
   LU_POINTS,
   LU_TEN_THOUSANDTHS_OF_INCHES
} jtapi_length_unit_t;

/************************************************************
 * MandatoryAtributesEnum
 *
 * Attributes that are mandatory and must be supported.
 ***********************************************************/
#define MA_ALL  "ALL"
#define MA_NONE "NONE"

/************************************************************
 * MediaCoatingEnum
 *
 * Type of coating on the media.
 ***********************************************************/
typedef enum
{
   MG_NOT_SET = 0,
   MG_NONE,
   MG_COATED,
   MG_GLOSSY,
   MG_HIGH_GLOSS,
   MG_INK_JET,
   MG_MATTE,
   MG_SATIN,
   MG_SEMI_GLOSS
} jtapi_media_coating_t;

/************************************************************
 * MediaColorEnum
 *
 * Color of the media.
 ***********************************************************/
typedef enum
{
   MC_NOT_SET = 0,
   MC_BLACK,
   MC_CLEAR_BLACK,
   MC_DARK_BLACK, 
   MC_LIGHT_BLACK,
   MC_BLUE, 
   MC_CLEAR_BLUE,
   MC_DARK_BLUE,
   MC_LIGHT_BLUE,
   MC_BROWN,
   MC_CLEAR_BROWN,
   MC_DARK_BROWN,
   MC_LIGHT_BROWN,
   MC_BUFF,
   MC_CLEAR_BUFF,
   MC_DARK_BUFF,
   MC_LIGHT_BUFF,
   MC_CYAN,
   MC_CLEAR_CYAN,        
   MC_DARK_CYAN,
   MC_LIGHT_CYAN,
   MC_GOLD,
   MC_CLEAR_GOLD,
   MC_DARK_GOLD,
   MC_LIGHT_GOLD,
   MC_GOLDENROD,
   MC_CLEAR_GODLENROD,
   MC_DARK_GOLDENROD,
   MC_LIGHT_GOLDENROD,
   MC_GRAY,
   MC_CLEAR_GRAY,
   MC_DARK_GRAY,
   MC_LIGHT_GRAY,
   MC_GREEN,
   MC_CLEAR_GREEN,
   MC_DARK_GREEN,
   MC_LIGHT_GREEN,
   MC_IVORY,
   MC_CLEAR_IVORY,
   MC_DARK_IVORY,
   MC_LIGHT_IVORY,
   MC_MAGENTA,
   MC_CLEAR_MAGENTA,
   MC_DARK_MAGENTA,
   MC_LIGHT_MAGENTA,
   MC_MULTI_COLOR,
   MC_CLEAR_MULTI_COLOR,
   MC_DARK_MULTI_COLOR,
   MC_LIGHT_MULTI_COLOR,
   MC_MUSTARD,
   MC_CLEAR_MUSTARD,
   MC_DARK_MUSTARD,
   MC_LIGHT_MUSTARD,
   MC_NO_COLOR,
   MC_CLEAR_NO_COLOR,
   MC_DARK_NO_COLOR,
   MC_LIGHT_NO_COLOR,
   MC_ORANGE,
   MC_CLEAR_ORANGE,
   MC_DARK_ORANGE,
   MC_LIGHT_ORANGE,
   MC_PINK,
   MC_CLEAR_PINK,
   MC_DARK_PINK,
   MC_LIGHT_PINK,
   MC_RED,
   MC_CLEAR_RED,
   MC_DARK_RED,
   MC_LIGHT_RED,
   MC_SILVER,
   MC_CLEAR_SILVER,
   MC_DARK_SILVER,
   MC_LIGHT_SILVER,
   MC_TURQUOISE,
   MC_CLEAR_TURQUOISE,
   MC_DARK_TURQUOISE,
   MC_LIGHT_TURQUOISE,
   MC_VIOLET,
   MC_CLEAR_VIOLET,
   MC_DARK_VIOLET,
   MC_LIGHT_VIOLET,
   MC_WHITE,
   MC_CLEAR_WHITE,
   MC_DARK_WHITE,
   MC_LIGHT_WHITE,
   MC_YELLOW,
   MC_CLEAR_YELLOW,
   MC_DARK_YELLOW,
   MC_LIGHT_YELLOW
} jtapi_media_color_t;

/************************************************************
 * MediaTypeEnum
 *
 * Type of the media.
 ***********************************************************/
#define MT_CARD_STOCK	     "CARD_STOCK"
#define MT_CONTINUOUS        "CONTINUOUS"
#define MT_CONTINUOUS_LONG   "CONTINUOUS_LONG"
#define MT_CONTINUOUS_SHORT  "CONTINUOUS_SHORT"  
#define MT_DISC              "DISC"
#define MT_ENVELOPE          "ENVELOPE"
#define MT_ENVELOPE_PLAIN    "ENVELOPE_PLAIN"
#define MT_ENVELOPE_WINDOW   "ENVELOPE_WINDOW"
#define MT_FILM_PHOTOGRAPHIC "FILM_PHOTOGRAPHIC"
#define MT_FILM_BLACK_PRINT  "FILM_BLACK_PRINT"
#define MT_FULL_CUT_TABS     "FULL_CUT_TABS"
#define MT_LABELS            "LABELS"
#define MT_MULTI_LAYER       "MULTI_LAYER"
#define MT_MULTI_PART_FORMS  "MULTI_PART_FORMS"
#define MT_PHOTOGRAPHIC      "PHOTOGRAPHIC"
#define MT_PRE_CUT_TABS      "PRE_CUT_TABS"
#define MT_ROLL              "ROLL" 
#define MT_STATIONERY        "STATIONERY "
#define MT_TAB_STOCK         "TAB_STOCK"
#define MT_TRANSPARENCY      "TRANSPARENCY"

/************************************************************
 * OutputBinEnum
 *
 * Names of output bins.
 ***********************************************************/
#define OB_BOOKLET         "BOOKLET"
#define OB_BOTTOM          "BOTTOM"
#define OB_CENTER          "CENTER"
#define OB_FACE_DOWN       "FACE_DOWN"
#define OB_FACE_UP         "FACE_UP"
#define OB_FIT_MEDIA       "FIT_MEDIA"
#define OB_LARGE_CAPACITY  "LARGE_CAPACITY"
#define OB_LEFT            "LEFT"
#define OB_MAILBOX_1       "MAILBOX_1"
#define OB_MAILBOX_2       "MAILBOX_2"
#define OB_MAILBOX_3       "MAILBOX_3"
#define OB_MIDDLE          "MIDDLE"
#define OB_MY_MAILBOX      "MY_MAILBOX"
#define OB_REAR            "REAR"
#define OB_RIGHT           "RIGHT"
#define OB_SIDE            "SIDE"
#define OB_STACKER_1       "STACKER_1"
#define OB_STACKER_2       "STACKER_2"
#define OB_STACKER_3       "STACKER_3"
#define OB_TOP             "TOP"
#define OB_TRAY_1          "TRAY_1"
#define OB_TRAY_2          "TRAY_2"
#define OB_TRAY_3          "TRAY_3"

/************************************************************
 * PageDeliveryEnum
 *
 * How the pages are to be ordered when output.
 ***********************************************************/
typedef enum
{
   PD_NOT_SET = 0,
   PD_FAN_FOLD,
   PD_REVERSE_ORDER_FACE_DOWN,
   PD_REVERSE_ORDER_FACE_UP,
   PD_SAME_ORDER_FACE_DOWN,
   PD_SAME_ORDER_FACE_UP
} jtapi_page_delivery_t;

/************************************************************
 * PositionEnum
 *
 * Position from which the operation is to occur.
 ***********************************************************/
typedef enum
{
   PS_NOT_SET = 0,
   PS_AFTER,
   PS_BEFORE
} jtapi_position_t;

/************************************************************
 * PreprintedEnum
 *
 * Whether or not the media is preprinted.
 ***********************************************************/
#define PP_BLANK
#define PP_LETTERHEAD
#define PP_PREPRINTED

/************************************************************
 * PresentationDirectionEnum
 *
 * Placement order of the pages.
 ***********************************************************/
typedef enum
{
   PR_NOT_SET = 0,
   PR_TO_RIGHT_TO_BOTTOM,
   PR_TO_BOTTOM_TO_RIGHT,
   PR_TO_LEFT_TO_BOTTOM,
   PR_TO_BOTTOM_TO_LEFT,
   PR_TO_RIGHT_TO_TOP,
   PR_TO_TOP_TO_RIGHT,
   PR_TO_LEFT_TO_TOP,
   PR_TO_TOP_TO_LEFT
} jtapi_presentation_direction_t;

/************************************************************
 * PrintContentOptimizeEnum
 *
 * What to optimize when printing.
 ***********************************************************/
typedef enum
{
   PC_NOT_SET = 0,
   PC_GRAPHICS,  
   PC_PHOTO,  
   PC_TEXT,
   PC_TEXT_AND_GRAPHICS
} jtapi_print_content_optimize_t;

/************************************************************
 * PrintQualityEnum
 *
 * The quality of the print to produce.
 ***********************************************************/
typedef enum
{
   PQ_NOT_SET = 0,
   PQ_DRAFT,  
   PQ_HIGH,  
   PQ_NORMAL
} jtapi_print_quality_t;

/************************************************************
 * ReferenceEdgeEnum
 *
 * Reference edge from where the operation is to occur.
 ***********************************************************/
typedef enum
{
   RE_NOT_SET = 0,
   RE_BOTTOM,  
   RE_LEFT,  
   RE_RIGHT,
   RE_TOP
} jtapi_reference_edge_t;

/************************************************************
 * RotationEnum
 *
 * How much to rotate an image.
 ***********************************************************/
typedef enum
{
   RT_NOT_SET = 0,
   RT_0_DEGREES,
   RT_90_DEGREES,
   RT_180_DEGREES,
   RT_270_DEGREES
} jtapi_rotation_t;

/************************************************************
 * SeparatorSheetEnum
 *
 * Type of start, separator/slip, end sheets to include 
 * with the job.
 ***********************************************************/
typedef enum
{
   SS_NOT_SET = 0,
   SS_AFTER_DOC_COPIES,
   SS_AFTER_JOB,
   SS_BEFORE_DOC_COPIES,
   SS_BEFORE_JOB,
   SS_BETWEEN_DOC_COPIES,
   SS_BETWEEN_JOB_COPIES,
} jtapi_separator_sheet_t;

/************************************************************
 * SheetSideEnum
 *
 * Side of the sheet to image on.
 ***********************************************************/
typedef enum
{
   SI_NOT_SET = 0,
   SI_BACK_SIDE,
   SI_FRONT_SIDE
} jtapi_sheet_side_t;

/************************************************************
 * SidesEnum
 *
 * Sides to image on.
 ***********************************************************/
typedef enum
{
   SD_NOT_SET = 0,
   SD_ONE_SIDED_FRONT,
   SD_ONE_SIDED_LONG_EDGE_BACK,
   SD_ONE_SIDED_SHORT_EDGE_BACK,
   SD_TWO_SIDED_LONG_EDGE,
   SD_TWO_SIDED_SHORT_EDGE
} jtapi_sides_t;

/************************************************************
 * StitchTypeEnum
 *
 * Whether or not to stitch and where to place the stitch.
 ***********************************************************/
typedef enum
{
   ST_NOT_SET = 0,
   ST_NONE,
   ST_CORNER,
   ST_SADDLE,
   ST_SIDE
} jtapi_stitch_type_t;

/************************************************************
 * SubscriptionEventEnum
 *
 * Events to subscribe for.
 ***********************************************************/
#define SE_JOB_CREATED        "JOB_CREATED"
#define SE_JOB_COMPLETED      "JOB_COMPLETED"
#define SE_JOB_STOPPED        "JOB_STOPPED"
#define SE_JOB_PROGRESS       "JOB_PROGRESS"
#define SE_JOB_CONFIG_CHANGED "JOB_CONFIG_CHANGED"
#define SE_JOB_STATE_CHANGED  "JOB_STATE_CHANGED"

/************************************************************
 * TrimmingTypeEnum
 *
 * Whether or not to trim pages
 ***********************************************************/
typedef enum
{
   TR_NOT_SET = 0,
   TR_NONE,
   TR_FACE,
   TR_GUTTER,
   TR_TAB,
   TR_TRIM
} jtapi_trimming_type_t;

/************************************************************
 * ValueTypeEnum
 *
 * The type of an attribute's value(s).
 ***********************************************************/
#define JTAPI_VT_DOUBLE     "VT_DOUBLE"
#define JTAPI_VT_INTEGER    "VT_INTEGER"
#define JTAPI_VT_OBJECT     "VT_OBJECT"
#define JTAPI_VT_STRING     "VT_STRING"

#endif /* JTAPI_ENUMS_H */
