/*********************************************************************
 * Job Ticket API (JTAPI)                                            
 *                                                                   
 * Copyright (c) 2003 International Business Machines Corp.          
 * Copyright (c) 2003 Free Standards Group.          
 *                                                                    
 *                    Common Public License - v 1.0 
 * THE ACCOMPANYING PROGRAM IS PROVIDED UNDER THE TERMS OF THIS COMMON 
 * PUBLIC LICENSE ("AGREEMENT"). ANY USE, REPRODUCTION OR DISTRIBUTION 
 * OF THE PROGRAM CONSTITUTES RECIPIENT'S ACCEPTANCE OF THIS AGREEMENT.   
 *
 * The Common Public License in its entirety is located in 
 * jtapi_cpl.h and applies to the contents of this file. 
 *********************************************************************/

#ifndef JTAPI_JOB_H
#define JTAPI_JOB_H

#include <jtapi.h>

/* Constant to use for the type of this jtapi object */
#define JTAPI_JOB_TYPE           "JTAPI_JOB"

/************************************************************
 * Job attributes
 ***********************************************************/
#define JOB_COMMENT                    "job-comment"
#define JOB_COPIES                     "job-copies"
#define JOB_DESTINATIONS               "job-destinations"
#define JOB_DOCUMENT_FORMAT            "job-document-format"
#define JOB_MEDIA                      "job-media"
#define JOB_NAME                       "job-name"
#define JOB_ROTATION                   "job-rotation"
#define JOB_PRINT_QUALITY              "job-print-quality"
#define JOB_SIDES                      "job-sides"
#define JOB_STITCHING                  "job-stitching"

/************************************************************
 * newJob - Creates a Job containing the provided Document.
 *
 * param jtapi_object_t* job - Pointer to job to be created
 * param jtapi_object_t document - Document to be contained 
 *      in this job
 *
 * return jtapi_status_t
 ***********************************************************/
jtapi_status_t newJob(jtapi_object_t* job, 
                      jtapi_object_t document);

/************************************************************
 * getDocuments - Get the documents that this job contains.
 *
 * param jtapi_object_t job - Job to get the documents from
 *
 * return jtapi_object_t* - List of this job's documents
 ***********************************************************/
jtapi_object_t* getDocuments(jtapi_object_t job);

#endif /* JTAPI_JOB_H */